@@ -30,6 +30,7 @@ lazy_static! {
     ("os", Nullary(os)),
     ("os_family", Nullary(os_family)),
     ("parent_directory", Unary(parent_directory)),
+    ("path_exists", Unary(path_exists)),
     ("quote", Unary(quote)),
     ("replace", Ternary(replace)),
     ("trim", Unary(trim)),
@@ -153,7 +154,7 @@ fn just_executable(_context: &FunctionContext) -> Result<String, String> {
   exe_path.to_str().map(str::to_owned).ok_or_else(|| {
     format!(
       "Executable path is not valid unicode: {}",
-      exe_path.to_string_lossy()
+      exe_path.display()
     )
   })
 }
@@ -167,7 +168,7 @@ fn justfile(context: &FunctionContext) -> Result<String, String> {
     .ok_or_else(|| {
       format!(
         "Justfile path is not valid unicode: {}",
-        context.search.justfile.to_string_lossy()
+        context.search.justfile.display()
       )
     })
 }
@@ -186,7 +187,7 @@ fn justfile_directory(context: &FunctionContext) -> Result<String, String> {
     .ok_or_else(|| {
       format!(
         "Justfile directory is not valid unicode: {}",
-        justfile_directory.to_string_lossy()
+        justfile_directory.display()
       )
     })
 }
@@ -210,6 +211,17 @@ fn parent_directory(_context: &FunctionContext, path: &str) -> Result<String, St
     .ok_or_else(|| format!("Could not extract parent directory from `{}`", path))
 }
 
+fn path_exists(context: &FunctionContext, path: &str) -> Result<String, String> {
+  Ok(
+    context
+      .search
+      .working_directory
+      .join(path)
+      .exists()
+      .to_string(),
+  )
+}
+
 fn quote(_context: &FunctionContext, s: &str) -> Result<String, String> {
   Ok(format!("'{}'", s.replace('\'', "'\\''")))
 }
