@@ -16,7 +16,7 @@ impl<'src> Display for Item<'src> {
       Item::Alias(alias) => write!(f, "{}", alias),
       Item::Assignment(assignment) => write!(f, "{}", assignment),
       Item::Comment(comment) => write!(f, "{}", comment),
-      Item::Recipe(recipe) => write!(f, "{}", recipe),
+      Item::Recipe(recipe) => write!(f, "{}", recipe.color_display(Color::never())),
       Item::Set(set) => write!(f, "{}", set),
     }
   }
